// Menu defines.
#define IDM_ABOUT 500
#define IDM_EXIT  510
#define IDM_FONT  520
#define IDM_PRINT 530

// Constant defines.
#define MAXPAGES 200
#define MAXLINES 2000

// String Table Defines
#define IDS_PROGNAME       1
#define IDS_MAINMENUNAME   2
#define IDS_MAINCLASSNAME  3

// Each document is an array of lines. A line is represented by the LINEINFO
// data structure. Each line contains the index to the first character in the
// buffer that begins the line (uFirstChar). A flag, bNewPara, is maintained
// to indicate if the current line is a new paragraph (in which case the
// flag is set to TRUE) or continuation of a previous line.  A third field,
// uWS holds the amount of white space (unused pixels on the display at the 
// end of the line). The amount of white space will be useful in applications
// that need to justify (right or center) the text. 

// The document is also organized as pages, where each page contains lines 
// from uFirstLine to uLastLine indices of the array. For example, if there 
// are 10 lines in the document, and only 5 lines per page, then 
// page[0].uFirstLine = 0 and page[0].uLastLine = 4 and page[1].uFirstLine
// = 5 and page[1].uLastLine = 9.

typedef struct tagLINEINFO {
                           		UINT uFirstChar; // Index to first char of this line in buffer
                           		UINT uWS; // unused white space (in pixels) left at end of line
                           		BOOL bNewPara; // TRUE indicates new paragraph
                           } LINEINFO;

typedef struct tagPAGEINFO {
                           		UINT uFirstLine; // Index to first line in this page
                           		UINT uLastLine; // last line in this page
                           } PAGEINFO;
                      


// Global variables defined in this header.  One .C file (INIT.C) should have
// IN_INIT #define'd prior to including this header -- it's in that
// C module where these variables will reside.

#ifdef IN_INIT
#define EXTERN
#endif

#ifndef IN_INIT
#define EXTERN extern
#endif

EXTERN HANDLE  ghInst;                     // Handle to this instance
EXTERN HWND    ghWnd;                      // Handle to main window
EXTERN LONG    glFileSize;                 // File size
EXTERN HGLOBAL ghMem;                      // handle to text in memory
EXTERN HGLOBAL ghLineMem;                  // handle to array of lines
EXTERN HGLOBAL ghPageMem;                  // handle to array of pages
EXTERN LPSTR   glpszText;                  // pointer to text in memory
EXTERN PAGEINFO FAR* glpPages;             // array of pages in document
EXTERN LINEINFO FAR* glpLines;             // array of lines in document
EXTERN UINT    guBuffLen;                  // length of text read in from file
EXTERN HFONT   ghFont;                     // font used for the text
EXTERN LOGFONT glf;                        // logfont used in the system
EXTERN RECT    grc;                        // contains the page boundaries
EXTERN UINT    guNumLines;                 // number of pages in document
EXTERN UINT    guNumPages;                 // number of lines in document
EXTERN UINT    guFirstVisLine;             // First visible line of the document
EXTERN UINT    guLastVisLine;              // Last visible line of the document
EXTERN UINT    guNumLinesPerPage;          // number of lines per printer page
EXTERN UINT    guNumLinesPerScrPage;       // number of lines per client area (for scrolling)
EXTERN HDC     ghPrnDC;                    // handle to printer DC
EXTERN HDC     ghScrDC;                    // handle to screen DC
EXTERN short   gnPrnXRes, gnPrnYRes;
EXTERN short   gnScrXRes, gnScrYRes;

